@@ -1,7 +1,7 @@
 use super::*;
+use crate::error::Result;
 use util::marshal::*;
 
-use anyhow::Result;
 use bytes::Bytes;
 
 impl Context {
@@ -15,15 +15,16 @@ impl Context {
             if let Some(state) = self.get_srtp_ssrc_state(header.ssrc) {
                 if let Some(replay_detector) = &mut state.replay_detector {
                     if !replay_detector.check(header.sequence_number as u64) {
-                        return Err(
-                            Error::SrtpSsrcDuplicated(header.ssrc, header.sequence_number).into(),
-                        );
+                        return Err(Error::SrtpSsrcDuplicated(
+                            header.ssrc,
+                            header.sequence_number,
+                        ));
                     }
                 }
 
                 roc = state.next_rollover_count(header.sequence_number);
             } else {
-                return Err(Error::SsrcMissingFromSrtp(header.ssrc).into());
+                return Err(Error::SsrcMissingFromSrtp(header.ssrc));
             }
         }
 
@@ -57,7 +58,7 @@ impl Context {
             if let Some(state) = self.get_srtp_ssrc_state(header.ssrc) {
                 roc = state.next_rollover_count(header.sequence_number);
             } else {
-                return Err(Error::SsrcMissingFromSrtp(header.ssrc).into());
+                return Err(Error::SsrcMissingFromSrtp(header.ssrc));
             }
         }
 
